# PayerMax
PayerMax SDK


## 安装
```sh
npm install payermax --save
# or
yarn add payermax
```


## 使用
详细参数说明，请参阅 [在线文档](https://docs.payermax.com/)

注：集成该 SDK 后， 所有 API 接口，不需要传参 `sign、merchantId`

```js
const PayerMax = require('payermax');

const payerMax = new PayerMax({
  // 商户秘钥（必填）
  secretKey: '秘钥',
  // 商户号（必填）
  merchantId: '商户号',
  // 测试环境 test，产线环境 prod（可选）
  // 默认 prod
  env: '联调环境',
  // https 配置（可选）
  // 详情参阅 NodeJS https 章节
  https: {
    // 超时时间
    timeout: 1000
  }
});
```

### 收款服务 通用 API
响应报文及请求参数请参阅在线文档-收款服务
```js
// 例：创建一个印尼订单
payerMax.payments.post({
  bizType: 'CUSTOMIZE',
  orderId: 'order1234456',
  userId: 'user123456',
  subject: 'shop title',
  countryCode: 'ID',
  currency: 'IDR',
  totalAmount: '1000',
  frontCallBackUrl: 'https://www.payermax.com',
  version: '2.3',
  ...
  // merchantId // 可选
  // sign // 可选
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

### 付款服务 通用 API
响应报文及请求参数请参阅在线文档-付款服务
```js
payerMax.payouts.post({
  bizType: 'singlePayment',
  version: '2.0'
  ...
  // merchantId // 可选
  // sign // 可选
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

## 指定 API

#### 创建收款订单
```js
// 详细参数说明，请参阅在线文档-收款服务-API收款
payerMax.payments.create({
  bizType: '产品编码',
  ...
  // merchantId // 可选
  // sign // 可选
  // version // 可选
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

#### 查询收款结果
```js
// 详细参数说明，请参阅在线文档-收款服务-结果查询-收款结果查询
payerMax.payments.queryReceiptResult({
  orderId: '商户订单号'
  // bizType // 可选
  // merchantId // 可选
  // sign // 可选
  // version // 可选
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

#### 发起退款
```js
// 详细参数说明，请参阅在线文档-收款服务-退款请求
payerMax.payments.refund({
  refundId: '商户退款请求流水号',
  orderId: '原商户订单号',
  amount: '原订单金额',
  currency: '货币代码',
  callbackUrl: '退款结果callBack URL',
  comment: '退款说明',
  email: '邮箱',
  // bizType // 可选
  // merchantId // 可选
  // sign // 可选
  // version // 可选
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

#### 查询退款结果
```js
// 详细参数说明，请参阅在线文档-收款服务-结果查询-退款结果查询
payerMax.payments.queryRefundResult({
  refundId: '商户退款请求流水号'
  // bizType // 可选
  // merchantId // 可选
  // sign // 可选
  // version // 可选
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

#### 创建付款订单
```js
// 详细参数说明，请参阅在线文档-收款服务-API收款
payerMax.payouts.create({
  bizType: '产品编码',
  ...
  // merchantId // 可选
  // sign // 可选
  // version // 可选
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

### 查询付款结果
```js
// 详细参数说明，请参阅在线文档-收款服务-结果查询
payerMax.payouts.queryResult({
  orderId: '商户订单号',
  // bizType // 可选
  // merchantId // 可选
  // sign // 可选
  // version // 可选
})
.then(res => console.log(res))
.catch(err => console.log(err));
```