'use strict';

const Request = require('../utils/request');
const { payment } = require('../config');

class Payments {
  constructor(options = {}) {
    const { secretKey, env, merchantId, https = {}} = options;
    this.api = new Request({
      config: {
        hostname: payment[env]['hostname'],
        path: payment[env]['path'],
        ...https
      },
      merchantId,
      secretKey
    });
  }

  // common api
  post(data) {
    return this.api.post(data);
  }

  // create order
  create(data) {
    return this.api.post({
      version: '2.3',
      ...data
    });
  }

  // query receipt result
  queryReceiptResult(data) {
    return this.api.post({
      version: '2.5',
      bizType: 'payTransQuery',
      ...data
    });
  }

  // refund
  refund(data) {
    return this.api.post({
      version: '2.1',
      bizType: 'refundApply',
      ...data
    });
  }

  // query refund result
  queryRefundResult(data) {
    return this.api.post({
      version: '2.1',
      bizType: 'refundQuery',
      ...data
    });
  }
}

module.exports = Payments;
