'use strict';

const https = require('https');
const { sign, verifySign } = require('./sign');

class Request {
  constructor(opt = {}) {
    this.options = {
      headers: {
        'Content-Type': 'application/json'
      },
      ...opt.config
    };
    this.secretKey = opt.secretKey;
    this.merchantId = opt.merchantId;
  }

  request(options, data) {
    return new Promise((resolve, reject) => {
      const req = https.request(options, (res) => {
        res.setEncoding('utf8');
        res.on('data', (responseData) => {
          const postData = JSON.parse(responseData);
          if (postData.bizCode === '0000') {
            if (verifySign(postData.data, this.secretKey, postData.data.sign)) {
              resolve(postData);
            } else {
              reject({ bizCode: '3000', displayMsg: 'Signature verification failed' });
            }
          } else {
            resolve(postData);
          }
        });
      });

      req.on('error', (error) => {
        reject(error);
      });

      req.on('timeout', () => {
        reject('[Network Error]: connect timed out');
      });

      data.merchantId = data.merchantId || this.merchantId;
      delete data.sign;
      data.sign = sign(data, this.secretKey);

      req.write(JSON.stringify(data));
      req.end();
    });
  }

  post(data) {
    const options = {
      method: 'POST',
      ...this.options
    };
    return this.request(options, data);
  }
}

module.exports = Request;
