const md5 = require('md5-node');

// compitable with nodejs < 7.0.0
if (typeof Object.entries !== Function) {
  Object.entries = function(obj) {
    const ownProps = Object.keys(obj);
    let i = ownProps.length;
    const resArray = new Array(i); // preallocate the Array

    while (i--) { resArray[i] = [ownProps[i], obj[ownProps[i]]]; }
    return resArray;
  };
}

/**
 * Sign
 * @param {Object} data api data
 * @param {String} key Merchant secret key
 * @returns
 */
function sign(data, key) {
  return md5(formatData(data) + 'key=' + key).toUpperCase();
}

/**
 * Signature verification
 * @param {Object} responseData
 * @param {*} key Merchant secret key
 * @param {*} responseSign
 * @returns
 */
function verifySign(responseData, key, responseSign) {
  return responseSign == sign(responseData, key);
}

function formatData(data) {
  let sign = '';
  const entries = Object.entries(data).sort();
  if (entries.length < 1) {
    return sign;
  }
  for (const [k, v] of entries) {
    if (k == null || v == null || k == 'sign') {
      continue;
    }
    if (v instanceof Object) {
      sign += k + '=' + formatData(v) + '&';
    } else {
      sign += k + '=' + v + '&';
    }
  }
  return sign;
}

module.exports = {
  sign,
  verifySign
};